@@ -134,9 +134,9 @@ chooseCentralOrgPkgSymbol <- function(x){
     if(exists("y", inherits=FALSE)){
         tables <- c("c.probes", tables)
     }
-    colTabs <- sapply(tables, FUN=dbListFields, con=con)
+    colTabs <- sapply(tables, FUN=dbListFields, con=con, simplify = FALSE)
     colTabs <- colTabs[grep("go_[mcb].+", names(colTabs), invert = TRUE)]
-    m <- unlist2(sapply(colTabs, match, field))  ## cannot ever be repeated
+    m <- unlist2(sapply(colTabs, match, field, simplify = FALSE))  ## cannot ever be repeated
     tab <- names(m)[!is.na(m)]
     if(length(tab)!=1){stop("Two fields in the source DB have the same name.")}
     tab
@@ -250,6 +250,10 @@ setMethod("keys", "GODb",
   }
 )
 
+setMethod("keys", "OrthologyDb",
+          function(x, keytype, ...) 
+    .ontoKeys(x, keytype, ...)
+    )
 
 ## new uses for keys:
 ## now TERM is a real key? (TODO: someone tell the keytypes)
@@ -341,6 +345,12 @@ setMethod("keytypes", "GODb",
     function(x) return(c("GOID","TERM","ONTOLOGY","DEFINITION")) ## only one type makes sense
 )
 
+setMethod("keytypes", "OrthologyDb",
+          function(x) 
+    .justFirstUpper(dbGetQuery(dbconn(x), "select name from names;")[,1])
+    )
+
+    
 ## Marc's TODO:
 ##X .5) make keytype so that it uses the mapping names instead of internal stuff
 ##X 1) make keytypes so that it returns all possible keytypes
